<?php        
namespace Concrete\Package\Salix;
use Package;
use BlockType;
use BlockTypeSet;
use PageTheme;
use PageTemplate;
use Concrete\Core\Attribute\Type as AttributeType;
use CollectionAttributeKey;
use Concrete\Core\Attribute\Key\Category as AttributeKeyCategory;
use Concrete\Core\Attribute\Set as AttributeSet;

class Controller extends Package {

	protected $pkgHandle = 'salix';
	protected $appVersionRequired = '5.7.5.6';
	protected $pkgVersion = '0.9.9';
	protected $pkgAllowsFullContentSwap = true;
		
	public function getPackageDescription()
	{
		return t("Salix is a Bootstrap theme featuring support for animations and multiple layouts.");
	}

	public function getPackageName()
	{
		return t("Salix");
	}
	
	public function install()
	{
		
		$pkg = parent::install();
		BlockTypeSet::add("salix","Salix", $pkg);
		
		$bt = BlockType::getByHandle('salix_accordion');
		if (!is_object($bt)) {
		    $bt = BlockType::installBlockType('salix_accordion', $pkg);
		}

		$bt = BlockType::getByHandle('salix_button');
		if (!is_object($bt)) {
		    $bt = BlockType::installBlockType('salix_button', $pkg);
		}

		$bt = BlockType::getByHandle('salix_highlight_box');
		if (!is_object($bt)) {
		    $bt = BlockType::installBlockType('salix_highlight_box', $pkg);
		}

		$bt = BlockType::getByHandle('salix_icons_font_awesome');
		if (!is_object($bt)) {
		    $bt = BlockType::installBlockType('salix_icons_font_awesome', $pkg);
		}

		$bt = BlockType::getByHandle('salix_social_icons');
		if (!is_object($bt)) {
		    $bt = BlockType::installBlockType('salix_social_icons', $pkg);
		}

		$bt = BlockType::getByHandle('salix_bootstrap_thumbnail');
		if (!is_object($bt)) {
		    $bt = BlockType::installBlockType('salix_bootstrap_thumbnail', $pkg);
		}

		$bt = BlockType::getByHandle('salix_image_feature');
		if (!is_object($bt)) {
		    $bt = BlockType::installBlockType('salix_image_feature', $pkg);
		}

		$this->pageTemplates($pkg);
		$this->installPageAttributes($pkg);
		PageTheme::add('salix', $pkg);				

  	}
	
	private function pageTemplates($pkg) {
		
		if (!PageTemplate::getByHandle('blog_entry')) {
            PageTemplate::add('blog_entry', t('Blog Entry'), 'right_sidebar.png', $pkg);
        }
		
        if (!PageTemplate::getByHandle('full')) {
            PageTemplate::add('full', t('Full'), 'full.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('full_v2')) {
            PageTemplate::add('full_v2', t('Full V2'), 'full.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('home_v1')) {
            PageTemplate::add('home_v1', t('Home V1'), 'full.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('home_v2')) {
            PageTemplate::add('home_v2', t('Home V2'), 'full.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('home_v1_animated')) {
            PageTemplate::add('home_v1_animated', t('Home V1 Animated'), 'full.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('home_v2_animated')) {
            PageTemplate::add('home_v2_animated', t('Home V2 Animated'), 'full.png', $pkg);
		}
        		
		if (!PageTemplate::getByHandle('left_sidebar')) {
            PageTemplate::add('left_sidebar', t('Left Sidebar'), 'left_sidebar.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('left_sidebar_v2')) {
            PageTemplate::add('left_sidebar_v2', t('Left Sidebar V2'), 'left_sidebar.png', $pkg);
        }	    
		
        if (!PageTemplate::getByHandle('portfolio_item')) {
            PageTemplate::add('portfolio_item', t('Portfolio Item'), 'right_sidebar.png', $pkg);
        }
		
        if (!PageTemplate::getByHandle('right_sidebar')) {
            PageTemplate::add('right_sidebar', t('Right Sidebar'), 'right_sidebar.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('right_sidebar_v2')) {
            PageTemplate::add('right_sidebar_v2', t('Right Sidebar V2'), 'right_sidebar.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('three_columns')) {
            PageTemplate::add('three_columns', t('Three Columns'), 'three_column.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('three_over_two')) {
            PageTemplate::add('three_over_two', t('Three Over Two'), 'three_column.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('two_columns')) {
            PageTemplate::add('two_columns', t('Two Columns'), 'two_column.png', $pkg);
        }
		
    }

  private function installPageAttributes(&$pkg) {
    // set attribute category 
    $akCatSet = AttributeSet::getByHandle('salix_set');
    if(!is_object($akCatSet)){
      $akCat = AttributeKeyCategory::getByHandle('collection');
      $akCat->setAllowAttributeSets(AttributeKeyCategory::ASET_ALLOW_SINGLE);
      $akCatSet = $akCat->addSet('salix_set', t('Salix Set'),$pkg);
    }
	
	$imgAttr = AttributeType::getByHandle('image_file'); 
  	$salixBannerImage = CollectionAttributeKey::getByHandle('salix_banner_image'); 
	 if( !is_object($salixBannerImage) ) {
     CollectionAttributeKey::add($imgAttr, 
        	array('akHandle' => 'salix_banner_image', 
          'akName' => t('Salix Banner Image'), 
        ),$pkg)->setAttributeSet($akCatSet); 
		
	 }
	$imgAttr = AttributeType::getByHandle('image_file'); 
  	$salixHomeFw1 = CollectionAttributeKey::getByHandle('salix_home_fw1'); 
	 if( !is_object($salixHomeFw1) ) {
     CollectionAttributeKey::add($imgAttr, 
        	array('akHandle' => 'salix_home_fw1', 
          'akName' => t('Salix Home Full Width 1'), 
        ),$pkg)->setAttributeSet($akCatSet); 
		
	 }
	 
	$imgAttr = AttributeType::getByHandle('image_file'); 
  	$salixHomeFw1 = CollectionAttributeKey::getByHandle('salix_home_fw2'); 
	 if( !is_object($salixHomeFw1) ) {
     CollectionAttributeKey::add($imgAttr, 
        	array('akHandle' => 'salix_home_fw2', 
          'akName' => t('Salix Home Full Width 2'), 
        ),$pkg)->setAttributeSet($akCatSet); 
		
	 }
	 
	$imgAttr = AttributeType::getByHandle('image_file'); 
  	$salixThumb = CollectionAttributeKey::getByHandle('salix_thumbnail'); 
	 if( !is_object($salixThumb) ) {
     CollectionAttributeKey::add($imgAttr, 
        	array('akHandle' => 'salix_thumbnail', 
          'akName' => t('Salix Thumbnail'), 
        ),$pkg)->setAttributeSet($akCatSet); 
 	
	  }
  }
  public function upgrade() {
    parent::upgrade();
    $pkg = Package::getByHandle('salix');
	$this->pageTemplates($pkg);

		if (!PageTemplate::getByHandle('full_v2')) {
            PageTemplate::add('full_v2', t('Full V2'), 'full.png', $pkg);
        }
		
		if (!PageTemplate::getByHandle('left_sidebar_v2')) {
            PageTemplate::add('left_sidebar_v2', t('Left Sidebar V2'), 'left_sidebar.png', $pkg);
        }
	    
		if (!PageTemplate::getByHandle('right_sidebar_v2')) {
            PageTemplate::add('right_sidebar_v2', t('Right Sidebar V2'), 'right_sidebar.png', $pkg);
        }
	}
}